@@ -16,10 +16,12 @@
 
 from spacy_syllables import SpacySyllables
 from stylo_metrix.pipeline.en.pos_tagger import POSTagger
+from stylo_metrix.pipeline.en.params import Params
 from stylo_metrix.pipeline.en.metrics import Metrics
 
 COMPONENTS = [
     SpacySyllables,
     POSTagger,
+    Params,
     Metrics,
 ]
