@@ -14,15 +14,30 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 
-from stylo_metrix.pipeline.en.dictionary_en import TAGS_DICT
+from stylo_metrix.pipeline.en.dictionary_en import TAGS_DICT, WORDS_POS, FUNCTION_WORDS
+
 
 """ METRICS FOR THE PRESENT TENSES [PASSIVE & ACTIVE VOICE]"""
 
 
 def classify_pos(token):
-    for pos, tags in TAGS_DICT.items():
-        if token.tag_ in tags:
-            return pos
+    for custom_pos, pos in TAGS_DICT.items():
+        if token.pos_ in pos:
+            return custom_pos
+
+
+def is_word(token):
+    return token._.pos in WORDS_POS
+
+
+def is_function_word(token):
+    if token.lemma_ in FUNCTION_WORDS:
+        return True
+
+
+def is_content_word(token):
+    if token._.is_word and token.lemma_ and not token._.is_function_word:
+        return True
 
 
 def present_simple(doc):
@@ -507,7 +522,7 @@ def future_cont(doc):
                 if t.tag_ == "VBG" and t.dep_ == "conj":
                     future_progr[t] = "future_progr"
 
-            if head in future_cont.keys():
+            if head in future_progr.keys():
                 future_progr[token] = "future_progr"
 
             for j in head.children:
@@ -566,9 +581,10 @@ def future_perfect(doc):
                         del future_perfect[tok]
 
             if head in future_perfect.keys():
-                for j, k in head.children:
-                    if j.text == "been" and k.text == "have":
-                        future_perfect[j] = "future_perfect"
+                for k in head.children:
+                    if k.text == "have":
+                        future_perfect[k] = "future_perfect"
+                    if k.text == "been":
                         future_perfect[k] = "future_perfect"
 
     return future_perfect
